==> Mapster-1.5.6.1.zip: Mapster/Locale/itIT.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "itIT")
if not L then return end

L["Accuracy"] = "Accuratezza"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Aggiusta la dimensione della Freccia del Giocatore sulla mappa per una visibilità migliore."
L["Alpha"] = "Trasparenza"
L["Battlegrounds"] = "Campi di Battaglia"
L["BattleMap"] = "BattleMap"
L["Blobs & Panels"] = "Pannelli & Punti"
L["Burning Crusade Instances"] = "Spedizioni Burning Crusade"
L["Burning Crusade Raids"] = "Incursioni Burning Crusade"
L["Cataclysm Instances"] = "Istanze Cataclysm"
L["Cataclysm Raids"] = "Incursioni Cataclysm"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Cambia la scala della mappa del mondo se non vuoi che appaia a tutto schermo quando la mappa è aperta."
L["Classic Instances"] = "Spedizioni Classiche"
L["Classic Raids"] = "Incursioni Classiche"
L["Coordinates"] = "Coordinate"
L["Cursor"] = "Cursore"
L["Debug"] = "Debug"
L["Disable Mouse"] = "Disabilita mouse"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Disabilita l'interattività del mouse della mappa principale, per esempio al cambio di zona."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Disabilita l'interattività del mouse della mappa principale quando questa è minimizzata, per esempio al cambio di zona."
L["EJ Icon Scale"] = "Scala Icona DI"
L["Enable BattleMap"] = "Abilita BattleMap"
L["Enable Coordinates"] = "Abilita Coordinate"
L["Enable FogClear"] = "Abilita FogClear"
L["Enable Group Icons"] = "Abilita icone del gruppo"
L["Enable Instance Maps"] = "Abilita Mappe Istanze"
L["FogClear"] = "FogClear"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "FogClear cerca e trova i tuoi dati nel tuo file SavfedVariables, ma quei dati possono corrompersi (o divenrate semplicemente troppo vecchi) con una nuova patch. Reimposta i dati se vedi dei segni di corruzzione sulla mappa."
L["Group Icons"] = "Gruppi Icone"
L["Hide Border"] = "Nascondi Margine"
L["Hide Completely"] = "Nascondi Completamente"
L["Hide Map Button"] = "Nascondi Bottone Mappa"
L["Hide Quest Panels"] = "Nascondi Pannelli Missioni"
L["Hide Textures"] = "Nascondi Textures"
L["Hide the borders of the big map."] = "Nascondi i margini della mappa grande."
L["Hide the borders of the minimized map."] = "Nascondi i margini della mappa ridotta."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Nascondi le texture intorno alla mappa del Campo di ABttaglia, lasciando solo la mappa pura e semplice."
L["Instance Maps"] = "Mappe Istanze"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster ti permette di controllare vari aspetti della Mappa del Mondo. Puoi cambiare lo stile della mappa, controllare le varie estensioni che aggiungono nuove funzionalità alla mappa, e configurare profili diversi per ogni tuo personaggio."
L["(Mini) Disable Mouse"] = "(Mini) Disabilita Mouse"
L["(Mini) Hide Border"] = "Nascondi Bordo (Mini)"
L["Minimized Alpha"] = "Trasparenza Mappa Ridotta"
L["Minimized Scale"] = "ScalaMappa Ridotta"
L["Note: You need to reload your UI after reseting the data!"] = "Nota: devi ricaricare la tua UI depo aver resettato tutti i dati!"
L["Only WorldMap Blobs"] = "Solo Punti Mappa Mondo"
L["Overlay Color"] = "Colore Overlay"
L["Pandaria Instances"] = "Spedizioni Pandaria"
L["Pandaria Raids"] = "Spedizioni Pandaria"
L["Player"] = "Giocatore"
L["PlayerArrow Scale"] = "Scala Freccia Giocatore"
L["POI Scale"] = "Scala Punti d'Interesse"
L["Reset FogClear Data"] = "Reimposta Dati FogClear"
L["Scale"] = "Scala"
L["Scale of the big map."] = "Scala della mappa grande."
L["Scale of the Encounter Journal Icons on the Map."] = "Scala dell'icona del Diario delle Istanze sulla Mappa."
L["Scale of the minimized map."] = "Scala della mappa ridotta."
L["Scale of the POI Icons on the Map."] = "Scala dell'icona dei Punti d'Interesse sulla Mappa."
L["Size on the Battle Map"] = "Dimensione della Mappa di Combattimento"
L["Size on the World Map"] = "Dimensione della Mappa del Mondo "
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Il modulo BattleMap ti permette di cambiare lo stile della Minimappa del campo di Battaglia, rimuovendo texture non necessarie oppure gli obbiettivi PvP."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Il modulo Coordinate ti permette di visualizzare l'attuale locazione, oppure le coordinate del tuo cursore del mouse dalla Mappa del Mondo."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Il modulo FogClear rimuove la Nebbia di Guerra dalla Mappa del Mondo, mostrando tutte le parti della mappa anche se non sono state effettivamente scoperte, con la possibilità di impostare un colore per evidenziare le zone non ancora scoperte."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Il modulo Gruppo Icone ti permette di controllare la dimensione delle icone dei membri dell'incursione o della spedizione sulla mappa del mondo."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "Il modulo Mappe Istanze ti permette di vedere le mappe delle istanze e dei Campi di Battaglia del gioco senza che tu sia necessariamente in quelle zone."
L["The transparency of the big map."] = "La trasparenza della mappa grande"
L["The transparency of the minimized map."] = "La trasparenza della mappa minimizzata"
L["Turn on debugging for the FogClear Module."] = "Abilita il debugging per il Modulo FogClear"
L["Wrath Instances"] = "Spedizioni Wrath of the Lich King"
L["Wrath Raids"] = "Incursioni Wrath of the Lich King "
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Puoi cambiare la trasparenza della mappa del mondo per vedere quello che ti corconda attorno a te mentre la mappa è aperta."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Puoi controllare l'accuratezza delle coordinate, per esempio, se hai bisogno delle coordinate esatte puoi impostare il valore a 2."

==> Mapster-1.6.6.zip: Mapster/Locale/itIT.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "itIT")
if not L then return end

L["Accuracy"] = "Accuratezza"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Aggiusta la dimensione della Freccia del Giocatore sulla mappa per una visibilità migliore."
L["Alpha"] = "Trasparenza"
L["BattleMap"] = "BattleMap"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Cambia la scala della mappa del mondo se non vuoi che appaia a tutto schermo quando la mappa è aperta."
L["Coordinates"] = "Coordinate"
L["Cursor"] = "Cursore"
L["Disable Mouse"] = "Disabilita mouse"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Disabilita l'interattività del mouse della mappa principale, per esempio al cambio di zona."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Disabilita l'interattività del mouse della mappa principale quando questa è minimizzata, per esempio al cambio di zona."
L["EJ Icon Scale"] = "Scala Icona DI"
L["Enable BattleMap"] = "Abilita BattleMap"
L["Enable Coordinates"] = "Abilita Coordinate"
L["Enable FogClear"] = "Abilita FogClear"
L["Enable Group Icons"] = "Abilita icone del gruppo"
-- L["Faded Alpha"] = "Faded Alpha"
L["FogClear"] = "FogClear"
L["Font Size"] = "Dimensione Carattere"
L["Font Size on the minimized map."] = "Dimensione CArattere per la mappa minimizzata"
-- L["Font Size on the normal map."] = "Font Size on the normal map."
L["Group Icons"] = "Gruppi Icone"
L["Hide Border"] = "Nascondi Margine"
L["Hide Map Button"] = "Nascondi Bottone Mappa"
L["Hide Textures"] = "Nascondi Textures"
L["Hide the borders of the big map."] = "Nascondi i margini della mappa grande."
L["Hide the borders of the minimized map."] = "Nascondi i margini della mappa ridotta."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Nascondi le texture intorno alla mappa del Campo di ABttaglia, lasciando solo la mappa pura e semplice."
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster ti permette di controllare vari aspetti della Mappa del Mondo. Puoi cambiare lo stile della mappa, controllare le varie estensioni che aggiungono nuove funzionalità alla mappa, e configurare profili diversi per ogni tuo personaggio."
L["(Mini) Disable Mouse"] = "(Mini) Disabilita Mouse"
L["(Mini) Font Size"] = "(Mini) Dimensione Carattere"
L["(Mini) Hide Border"] = "Nascondi Bordo (Mini)"
L["Minimized Alpha"] = "Trasparenza Mappa Ridotta"
L["Minimized Scale"] = "ScalaMappa Ridotta"
L["Overlay Color"] = "Colore Overlay"
L["Player"] = "Giocatore"
L["PlayerArrow Scale"] = "Scala Freccia Giocatore"
L["POI Scale"] = "Scala Punti d'Interesse"
L["Scale"] = "Scala"
L["Scale of the big map."] = "Scala della mappa grande."
L["Scale of the Encounter Journal Icons on the Map."] = "Scala dell'icona del Diario delle Istanze sulla Mappa."
L["Scale of the minimized map."] = "Scala della mappa ridotta."
L["Scale of the POI Icons on the Map."] = "Scala dell'icona dei Punti d'Interesse sulla Mappa."
L["Size on the Battle Map"] = "Dimensione della Mappa di Combattimento"
L["Size on the World Map"] = "Dimensione della Mappa del Mondo "
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Il modulo BattleMap ti permette di cambiare lo stile della Minimappa del campo di Battaglia, rimuovendo texture non necessarie oppure gli obbiettivi PvP."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Il modulo Coordinate ti permette di visualizzare l'attuale locazione, oppure le coordinate del tuo cursore del mouse dalla Mappa del Mondo."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Il modulo FogClear rimuove la Nebbia di Guerra dalla Mappa del Mondo, mostrando tutte le parti della mappa anche se non sono state effettivamente scoperte, con la possibilità di impostare un colore per evidenziare le zone non ancora scoperte."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Il modulo Gruppo Icone ti permette di controllare la dimensione delle icone dei membri dell'incursione o della spedizione sulla mappa del mondo."
-- L["The map will fade out to the configured Fade Alpha level when you start moving."] = "The map will fade out to the configured Fade Alpha level when you start moving."
L["The transparency of the big map."] = "La trasparenza della mappa grande"
-- L["The transparency of the map while you are moving and the map is faded."] = "The transparency of the map while you are moving and the map is faded."
L["The transparency of the minimized map."] = "La trasparenza della mappa minimizzata"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Puoi cambiare la trasparenza della mappa del mondo per vedere quello che ti corconda attorno a te mentre la mappa è aperta."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Puoi controllare l'accuratezza delle coordinate, per esempio, se hai bisogno delle coordinate esatte puoi impostare il valore a 2."
